@@ -89,7 +89,8 @@ boxed_new_resolve(JSContext *context,
                   JSObject **objp)
 {
     Boxed *priv;
-    const char *name;
+    char *name;
+    JSBool ret = JS_FALSE;
 
     *objp = NULL;
 
@@ -100,7 +101,8 @@ boxed_new_resolve(JSContext *context,
     gjs_debug_jsprop(GJS_DEBUG_GBOXED, "Resolve prop '%s' hook obj %p priv %p", name, obj, priv);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class */
+        goto out; /* wrong class */
+
 
     if (priv->gboxed == NULL) {
         /* We are the prototype, so look for methods and other class properties */
@@ -127,7 +129,8 @@ boxed_new_resolve(JSContext *context,
                           g_base_info_get_namespace( (GIBaseInfo*) priv->info),
                           g_base_info_get_name( (GIBaseInfo*) priv->info));
                 g_base_info_unref( (GIBaseInfo*) method_info);
-                return JS_TRUE;
+                ret = JS_TRUE;
+                goto out;
             }
 
             gjs_debug(GJS_DEBUG_GBOXED,
@@ -140,7 +143,7 @@ boxed_new_resolve(JSContext *context,
 
             if (gjs_define_function(context, boxed_proto, method_info) == NULL) {
                 g_base_info_unref( (GIBaseInfo*) method_info);
-                return JS_FALSE;
+                goto out;
             }
 
             *objp = boxed_proto; /* we defined the prop in object_proto */
@@ -156,8 +159,11 @@ boxed_new_resolve(JSContext *context,
          * hooks, not this resolve hook.
          */
     }
+    ret = JS_TRUE;
 
-    return JS_TRUE;
+ out:
+    g_free(name);
+    return ret;
 }
 
 /* Check to see if jsval passed in is another Boxed object of the same,
@@ -233,24 +239,19 @@ boxed_new(JSContext   *context,
             if ((flags & GI_FUNCTION_IS_CONSTRUCTOR) != 0 &&
                 g_callable_info_get_n_args((GICallableInfo*) func_info) == 0) {
 
-                jsval rval;
-                void *gboxed;
+                GIArgument rval;
+                GError *error = NULL;
 
-                rval = JSVAL_NULL;
-                gjs_invoke_c_function_uncached(context, func_info, obj,
-                                               0, NULL, &rval);
+                if (!g_function_info_invoke(func_info, NULL, 0, NULL, 0, &rval, &error)) {
+                    gjs_throw(context, "Failed to invoke boxed constructor: %s", error->message);
+                    g_clear_error(&error);
+                    g_base_info_unref((GIBaseInfo*) func_info);
+                    return JS_FALSE;
+                }
 
                 g_base_info_unref((GIBaseInfo*) func_info);
 
-                if (JSVAL_IS_NULL(rval))
-                    return JS_FALSE;
-
-                /* We are somewhat wasteful here; invoke_c_function() above
-                 * creates a JSObject wrapper for the boxed that we immediately
-                 * discard.
-                 */
-                gboxed = gjs_c_struct_from_boxed(context, JSVAL_TO_OBJECT(rval));
-                priv->gboxed = g_boxed_copy (gtype, gboxed);
+                priv->gboxed = rval.v_pointer;
 
                 gjs_debug_lifecycle(GJS_DEBUG_GBOXED,
                                     "JSObject created with boxed instance %p type %s",
@@ -334,7 +335,7 @@ boxed_init_from_props(JSContext   *context,
 
     while (!JSID_IS_VOID(prop_id)) {
         GIFieldInfo *field_info;
-        const char *name;
+        char *name;
         jsval value;
 
         if (!gjs_get_string_id(context, prop_id, &name))
@@ -344,15 +345,18 @@ boxed_init_from_props(JSContext   *context,
         if (field_info == NULL) {
             gjs_throw(context, "No field %s on boxed type %s",
                       name, g_base_info_get_name((GIBaseInfo *)priv->info));
+            g_free(name);
             goto out;
         }
 
-        if (!gjs_object_require_property(context, props, "property list", name, &value))
-            goto out;
-
-        if (!boxed_set_field_from_value(context, priv, field_info, value)) {
+        if (!gjs_object_require_property(context, props, "property list", name, &value)) {
+            g_free(name);
             goto out;
         }
+        g_free(name);
+
+        if (!boxed_set_field_from_value(context, priv, field_info, value))
+            goto out;
 
         prop_id = JSID_VOID;
         if (!JS_NextProperty(context, iter, &prop_id))
@@ -361,7 +365,7 @@ boxed_init_from_props(JSContext   *context,
 
     success = TRUE;
 
-out:
+ out:
     g_hash_table_destroy(field_map);
 
     return success;
@@ -410,13 +414,10 @@ boxed_init(JSContext   *context,
  * identify the prototype as an object of our class with NULL private
  * data.
  */
-static JSBool
-boxed_constructor(JSContext *context,
-                  JSObject  *obj,
-                  uintN      argc,
-                  jsval     *argv,
-                  jsval     *retval)
+GJS_NATIVE_CONSTRUCTOR_DECLARE(boxed)
 {
+    JSObject *object = NULL;                            \
+    jsval *argv = JS_ARGV(context, vp);
     Boxed *priv;
     Boxed *proto_priv;
     JSClass *obj_class;
@@ -424,28 +425,27 @@ boxed_constructor(JSContext *context,
     JSObject *proto;
     gboolean is_proto;
 
-    if (!gjs_check_constructing(context))
-        return JS_FALSE;
+    GJS_NATIVE_CONSTRUCTOR_PRELUDE(boxed);
 
     priv = g_slice_new0(Boxed);
 
     GJS_INC_COUNTER(boxed);
 
-    g_assert(priv_from_js(context, obj) == NULL);
-    JS_SetPrivate(context, obj, priv);
+    g_assert(priv_from_js(context, object) == NULL);
+    JS_SetPrivate(context, object, priv);
 
     gjs_debug_lifecycle(GJS_DEBUG_GBOXED,
                         "boxed constructor, obj %p priv %p",
-                        obj, priv);
+                        object, priv);
 
-    proto = JS_GetPrototype(context, obj);
+    proto = JS_GetPrototype(context, object);
     gjs_debug_lifecycle(GJS_DEBUG_GBOXED, "boxed instance __proto__ is %p", proto);
 
     /* If we're constructing the prototype, its __proto__ is not the same
      * class as us, but if we're constructing an instance, the prototype
      * has the same class.
      */
-    obj_class = JS_GET_CLASS(context, obj);
+    obj_class = JS_GET_CLASS(context, object);
     proto_class = JS_GET_CLASS(context, proto);
 
     is_proto = (obj_class != proto_class);
@@ -491,14 +491,15 @@ boxed_constructor(JSContext *context,
                 GType gtype = g_registered_type_info_get_g_type( (GIRegisteredTypeInfo*) priv->info);
                 if (gtype != G_TYPE_NONE) {
                     priv->gboxed = g_boxed_copy(gtype, source_priv->gboxed);
+                    GJS_NATIVE_CONSTRUCTOR_FINISH(boxed);
                     return JS_TRUE;
                 }
             }
 
-            if (!boxed_new(context, obj, priv))
+            if (!boxed_new(context, object, priv))
                 return JS_FALSE;
 
-            if (!boxed_init(context, obj, priv, argc, argv))
+            if (!boxed_init(context, object, priv, argc, argv))
                 return JS_FALSE;
 
         } else if (!JSVAL_IS_NULL(unthreadsafe_template_for_constructor.parent_jsval)) {
@@ -510,7 +511,7 @@ boxed_constructor(JSContext *context,
             /* We never actually read the reserved slot, but we put the parent object
              * into it to hold onto the parent object.
              */
-            JS_SetReservedSlot(context, obj, 0,
+            JS_SetReservedSlot(context, object, 0,
                                unthreadsafe_template_for_constructor.parent_jsval);
 
             unthreadsafe_template_for_constructor.parent_jsval = JSVAL_NULL;
@@ -525,12 +526,13 @@ boxed_constructor(JSContext *context,
             unthreadsafe_template_for_constructor.gboxed = NULL;
         } else {
             GType gtype = g_registered_type_info_get_g_type( (GIRegisteredTypeInfo*) priv->info);
-
+            JSBool retval;
+            
             if (gtype != G_TYPE_NONE) {
                 priv->gboxed = g_boxed_copy(gtype,
                                             unthreadsafe_template_for_constructor.gboxed);
             } else if (priv->can_allocate_directly) {
-                if (!boxed_new_direct(context, obj, priv))
+                if (!boxed_new_direct(context, object, priv))
                     return JS_FALSE;
 
                 memcpy(priv->gboxed,
@@ -544,10 +546,15 @@ boxed_constructor(JSContext *context,
 
             unthreadsafe_template_for_constructor.gboxed = NULL;
 
-            return priv->gboxed != NULL;
+            retval = priv->gboxed != NULL;
+            if (retval)
+                GJS_NATIVE_CONSTRUCTOR_FINISH(boxed);
+            return retval;
         }
     }
 
+    GJS_NATIVE_CONSTRUCTOR_FINISH(boxed);
+
     return JS_TRUE;
 }
 
@@ -841,6 +848,9 @@ static JSBool
 boxed_field_setter (JSContext *context,
                     JSObject  *obj,
                     jsid       id,
+#ifdef HAVE_JS_STRICTPROPERTYSTUB
+                    JSBool     strict,
+#endif
                     jsval     *value)
 {
     Boxed *priv;
@@ -949,7 +959,7 @@ static struct JSClass gjs_boxed_class = {
     JS_PropertyStub,
     JS_PropertyStub,
     JS_PropertyStub,
-    JS_PropertyStub,
+    JS_StrictPropertyStub,
     JS_EnumerateStub,
     (JSResolveOp) boxed_new_resolve, /* needs cast since it's the new resolve signature */
     JS_ConvertStub,
@@ -1048,6 +1058,7 @@ struct_is_simple(GIStructInfo *info)
             case GI_TYPE_TAG_UINT64:
             case GI_TYPE_TAG_FLOAT:
             case GI_TYPE_TAG_DOUBLE:
+            case GI_TYPE_TAG_UNICHAR:
                 break;
             case GI_TYPE_TAG_VOID:
             case GI_TYPE_TAG_GTYPE:
@@ -1164,7 +1175,7 @@ gjs_define_boxed_class(JSContext    *context,
                                            * none - just name the prototype like
                                            * Math - rarely correct)
                                            */
-                                          boxed_constructor,
+                                          gjs_boxed_constructor,
                                           /* number of constructor args (less can be passed) */
                                           1,
                                           /* props of prototype */
@@ -1175,8 +1186,10 @@ gjs_define_boxed_class(JSContext    *context,
                                           NULL,
                                           /* funcs of constructor, MyConstructor.myfunc() */
                                           NULL);
-    if (prototype == NULL)
+    if (prototype == NULL) {
+        gjs_log_exception(context, NULL);
         gjs_fatal("Can't init class %s", constructor_name);
+    }
 
     g_assert(gjs_object_has_property(context, in_object, constructor_name));
 
