@@ -209,7 +209,7 @@ union_new(JSContext   *context,
  */
 GJS_NATIVE_CONSTRUCTOR_DECLARE(union)
 {
-    GJS_NATIVE_CONSTRUCTOR_VARIABLES(union)
+    JSObject *object = NULL;                            \
     Union *priv;
     Union *proto_priv;
     JSClass *obj_class;
@@ -355,7 +355,7 @@ static struct JSClass gjs_union_class = {
     JS_PropertyStub,
     JS_PropertyStub,
     JS_PropertyStub,
-    JS_PropertyStub,
+    JS_StrictPropertyStub,
     JS_EnumerateStub,
     (JSResolveOp) union_new_resolve, /* needs cast since it's the new resolve signature */
     JS_ConvertStub,
