@@ -967,7 +967,7 @@ importer_new_resolve(JSContext *context,
  */
 GJS_NATIVE_CONSTRUCTOR_DECLARE(importer)
 {
-    GJS_NATIVE_CONSTRUCTOR_VARIABLES(importer)
+    JSObject *object = NULL;                            \
     Importer *priv;
 
     GJS_NATIVE_CONSTRUCTOR_PRELUDE(importer);
@@ -1043,6 +1043,7 @@ importer_new(JSContext    *context)
     JSObject *importer;
     Importer *priv;
     JSObject *global;
+    (void) priv;
 
     global = gjs_get_import_global(context);
 
@@ -1083,8 +1084,6 @@ importer_new(JSContext    *context)
     if (importer == NULL)
         gjs_fatal("No memory to create ns object");
 
-    priv = priv_from_js(context, importer);
-
     return importer;
 }
 
